@@ -14,7 +14,7 @@ function(survObj, priorPara, initial, rw = FALSE, mcmcPara, num.reps, thin, chai
 	s		<- priorPara$s
 	J		<- priorPara$J	<- length(priorPara$s)
 	
-	intv 				<- setting.interval(survObj$t, survObj$di, 							priorPara$s, priorPara$J)
+	intv 				<- setting.interval(survObj$t, survObj$di, priorPara$s, priorPara$J)
 	priorPara$ind.r		<- intv$ind.r
 	priorPara$ind.d		<- intv$ind.d
 	priorPara$ind.r_d	<- intv$ind.r_d	
@@ -71,8 +71,10 @@ function(survObj, priorPara, initial, rw = FALSE, mcmcPara, num.reps, thin, chai
 	# MCMC sampling
 
 	for(M in 1:num.reps){	
-	
-		cat("Chain", chain, "Iteration", M, fill=TRUE);
+        if(M %% 1000 == 0)
+        {
+            cat("Chain", chain, "Iteration", M, fill=TRUE);
+        }
 		
 		# Updating regression parameters
 		
@@ -155,7 +157,10 @@ function(survObj, priorPara, initial, rw = FALSE, mcmcPara, num.reps, thin, chai
 		} # the end of MCMC sampling
 		
 	
-	list(beta.p = beta.p, h.p = h.p, tauSq.p = tauSq.p, mcmcOutcome = mcmcOutcome)
+	ret <- list(beta.p = beta.p, h.p = h.p, tauSq.p = tauSq.p, mcmcOutcome = mcmcOutcome, t=survObj$t, di=survObj$di)
+    
+    class(ret) <- "psbcEN"
+    return(ret)
 	
 	} # end of "psbcGrp" function
 
